@@ -35,8 +35,13 @@ from .dataset.references import (
     QuarterOverQuarter,
     WeekOverWeek,
     YearOverYear,
+    DaysOverDays,
+    WeeksOverWeeks,
+    MonthsOverMonths,
+    QuartersOverQuarters,
+    YearsOverYears,
 )
 from .exceptions import DataSetException
 from .widgets import *
 
-__version__ = "7.4.1"
+__version__ = "7.8.4"
