@@ -10,7 +10,8 @@ from pypika import (
 )
 from pypika.terms import Function
 
-from fireant.middleware.decorators import (apply_middlewares, connection_middleware)
+from fireant.exceptions import QueryCancelled
+from fireant.middleware.decorators import apply_middlewares, connection_middleware
 
 
 class Database(object):
@@ -43,6 +44,17 @@ class Database(object):
         """
         raise NotImplementedError
 
+    def cancel(self, connection):
+        """
+        Cancel any running query.
+        """
+        if hasattr(connection, "cancel"):
+            connection.cancel()
+        else:
+            # A default cancel for databases for which no specific cancel is implemented
+            # This will force an exit of the connection context manager
+            raise QueryCancelled("Query was cancelled")
+
     def get_column_definitions(self, schema, table, connection=None):
         """
         Return a list of column name, column data type pairs.
@@ -106,9 +118,7 @@ class Database(object):
         connection = kwargs.get("connection")
         dataframes = []
         for query in queries:
-            dataframes.append(
-                pd.read_sql(query, connection, coerce_float=True, parse_dates=parse_dates)
-            )
+            dataframes.append(pd.read_sql(query, connection, coerce_float=True, parse_dates=parse_dates))
         return dataframes
 
     def fetch_dataframe(self, query, **kwargs):
