@@ -11,6 +11,7 @@ from pypika.terms import CustomFunction, Interval, Parameter
 from . import sql_types
 from .base import Database
 from .type_engine import TypeEngine
+from ..exceptions import QueryCancelled
 
 _DateFormat = CustomFunction('DATE_FORMAT', ['field', 'date_format'])
 _DateSub = CustomFunction('DATE_SUB', ['field', 'interval'])
@@ -37,6 +38,7 @@ class _CustomMySQLInterval(terms.Function):
     Fireant needs a more flexible Interval query string generator than this
     to mimicking the Vertica TRUNC function, so this is defined locally here.
     """
+
     def __init__(self, field, unit):
         super().__init__('INTERVAL', field, unit)
         self.field = field
@@ -51,41 +53,28 @@ class MySQLDatabase(Database):
     """
     MySQL client that uses the PyMySQL module.
     """
+
     # The pypika query class to use for constructing queries
     query_cls = MySQLQuery
 
-    def __init__(self, host='localhost', port=3306, database=None,
-                 user=None, password=None, charset='utf8mb4', **kwags):
-        super(MySQLDatabase, self).__init__(host, port, database, **kwags)
+    def __init__(
+        self,
+        host='localhost',
+        port=3306,
+        database=None,
+        user=None,
+        password=None,
+        charset='utf8mb4',
+        read_timeout=None,
+        **kwargs,
+    ):
+        super(MySQLDatabase, self).__init__(host, port, database, **kwargs)
         self.user = user
         self.password = password
         self.charset = charset
+        self.read_timeout = read_timeout
         self.type_engine = MySQLTypeEngine()
 
-    def _get_connection_class(self):
-        # Nesting inside a function so the import does not cause issues if users have not installed the 'mysql' extra
-        # when installing
-        import pymysql
-
-        class MySQLConnection(pymysql.connections.Connection):
-            """
-            PyMySQL has deprecated context managers in the connection class.
-            To make the functionality consistent with other database drivers, we override
-            the context manager to return the connection instead of the cursor object.
-
-            This also fixes an issue where connections were not being closed in the current PyMySQL
-            context manager implementation!
-            https://github.com/PyMySQL/PyMySQL/issues/735
-            """
-
-            def __enter__(self):
-                return self
-
-            def __exit__(self, exc, value, traceback):
-                self.close()
-
-        return MySQLConnection
-
     def connect(self):
         """
         Returns a MySQL connection
@@ -93,10 +82,29 @@ class MySQLDatabase(Database):
         :return: pymysql Connection class
         """
         import pymysql
-        connection_class = self._get_connection_class()
-        return connection_class(host=self.host, port=self.port, db=self.database,
-                                user=self.user, password=self.password,
-                                charset=self.charset, cursorclass=pymysql.cursors.Cursor)
+
+        return pymysql.connect(
+            host=self.host,
+            port=self.port,
+            db=self.database,
+            user=self.user,
+            password=self.password,
+            charset=self.charset,
+            read_timeout=self.read_timeout,
+            cursorclass=pymysql.cursors.Cursor,
+        )
+
+    def cancel(self, connection):
+        try:
+            connection.kill(connection.thread_id())
+        except RuntimeError:
+            # The kill operation seems to always throw a RuntimeError after sending the command while reading the
+            # OK packet. Ignore this exception and raise our own QueryCancelled.
+            # A bunch of other errors will be thrown as well because the socket has been set to None and calls are still
+            # being made to the connector, but that's fine.
+            pass
+        finally:
+            raise QueryCancelled("Query was cancelled")
 
     def trunc_date(self, field, interval):
         if interval == 'hour':
@@ -108,9 +116,11 @@ class MySQLDatabase(Database):
         elif interval == 'month':
             return _DateFormat(field, '%Y-%m-01')
         elif interval == 'quarter':
-            return _MakeDate(_Year(_Timestamp(field)), 1) \
-                   + _CustomMySQLInterval(_Quarter(_Timestamp(field)), 'QUARTER') \
-                   - Interval(quarters=1, dialect=Dialects.MYSQL)
+            return (
+                _MakeDate(_Year(_Timestamp(field)), 1)
+                + _CustomMySQLInterval(_Quarter(_Timestamp(field)), 'QUARTER')
+                - Interval(quarters=1, dialect=Dialects.MYSQL)
+            )
         elif interval == 'year':
             return _DateFormat(field, '%Y-01-01')
         else:
@@ -127,13 +137,14 @@ class MySQLDatabase(Database):
     def get_column_definitions(self, schema, table, connection=None):
         columns = Table('columns', schema='INFORMATION_SCHEMA')
 
-        columns_query = MySQLQuery \
-            .from_(columns) \
-            .select(columns.column_name, columns.column_type) \
-            .where(columns.table_schema == Parameter('%(schema)s')) \
-            .where(columns.field('table_name') == Parameter('%(table)s')) \
-            .distinct() \
+        columns_query = (
+            MySQLQuery.from_(columns)
+            .select(columns.column_name, columns.column_type)
+            .where(columns.table_schema == Parameter('%(schema)s'))
+            .where(columns.field('table_name') == Parameter('%(table)s'))
+            .distinct()
             .orderby(columns.column_name)
+        )
 
         return self.fetch(str(columns_query), parameters=dict(schema=schema, table=table), connection=connection)
 
@@ -145,9 +156,7 @@ class MySQLDatabase(Database):
         :param file_path: The path of the file to be imported.
         :param connection: (Optional) The connection to execute this query with.
         """
-        import_query = MySQLQuery \
-            .load(file_path) \
-            .into(table)
+        import_query = MySQLQuery.load(file_path).into(table)
 
         self.execute(str(import_query), connection=connection)
 
@@ -159,10 +168,7 @@ class MySQLDatabase(Database):
         :param columns: The columns of the new temporary table.
         :param connection: (Optional) The connection to execute this query with.
         """
-        create_query = MySQLQuery \
-            .create_table(table) \
-            .temporary() \
-            .columns(*columns)
+        create_query = MySQLQuery.create_table(table).temporary().columns(*columns)
 
         self.execute(str(create_query), connection=connection)
 
@@ -174,10 +180,7 @@ class MySQLDatabase(Database):
         :param select_query: The query to be used for selecting data of an existing table for the new temporary table.
         :param connection: (Optional) The connection to execute this query with.
         """
-        create_query = MySQLQuery \
-            .create_table(table) \
-            .temporary() \
-            .as_select(select_query)
+        create_query = MySQLQuery.create_table(table).temporary().as_select(select_query)
 
         self.execute(str(create_query), connection=connection)
 
