@@ -1,9 +1,12 @@
 from pypika import (
-    Parameter, PostgreSQLQuery,
+    Parameter,
+    PostgreSQLQuery,
     Table,
-    functions as fn,
     terms,
+    Dialects,
 )
+from pypika.terms import Node
+from pypika.utils import format_quotes
 
 from .base import Database
 
@@ -17,6 +20,29 @@ class DateTrunc(terms.Function):
         super(DateTrunc, self).__init__('DATE_TRUNC', date_format, field, alias=alias)
 
 
+class PostgreSQLTimestamp(Node):
+    def __init__(self, timestamp):
+        self.timestamp = timestamp
+
+    def get_sql(self, secondary_quote_char: str = "'", **kwargs) -> str:
+        formatted_timestamp = format_quotes(self.timestamp.isoformat(), secondary_quote_char)
+        return f"TIMESTAMP {formatted_timestamp}"
+
+
+class PostgresDateAdd(terms.Function):
+    def __init__(self, field, date_part, interval):
+        wrapped_field = self.wrap_constant(field, PostgreSQLTimestamp)
+        if date_part == "quarter":
+            date_part = "month"
+            interval *= 3
+
+        interval_term = terms.Interval(**{f'{str(date_part)}s': interval, 'dialect': Dialects.POSTGRESQL})
+        super().__init__('DATEADD', wrapped_field, interval_term)
+
+    def get_function_sql(self, **kwargs):
+        return " + ".join(self.get_arg_sql(arg, **kwargs) for arg in self.args)
+
+
 class PostgreSQLDatabase(Database):
     """
     PostgreSQL client that uses the psycopg module.
@@ -25,15 +51,7 @@ class PostgreSQLDatabase(Database):
     # The pypika query class to use for constructing queries
     query_cls = PostgreSQLQuery
 
-    def __init__(
-        self,
-        host="localhost",
-        port=5432,
-        database=None,
-        user=None,
-        password=None,
-        **kwargs
-    ):
+    def __init__(self, host="localhost", port=5432, database=None, user=None, password=None, **kwargs):
         super().__init__(host, port, database, **kwargs)
         self.user = user
         self.password = password
@@ -53,10 +71,10 @@ class PostgreSQLDatabase(Database):
         return DateTrunc(field, str(interval))
 
     def date_add(self, field, date_part, interval):
-        return fn.DateAdd(str(date_part), interval, field)
+        return PostgresDateAdd(field, date_part, interval)
 
     def get_column_definitions(self, schema, table, connection=None):
-        columns = Table("columns", schema="INFORMATION_SCHEMA")
+        columns = Table("columns", schema="information_schema")
 
         columns_query = (
             PostgreSQLQuery.from_(columns, immutable=False)
