@@ -1,5 +1,6 @@
 from pypika import (
-    Parameter, Tables,
+    Parameter,
+    Tables,
     VerticaQuery,
     functions as fn,
     terms,
@@ -60,28 +61,38 @@ class VerticaDatabase(Database):
         database="vertica",
         user="vertica",
         password=None,
-        read_timeout=None,
-        **kwags
+        connection_timeout=None,
+        log_level=None,
+        **kwargs,
     ):
-        super(VerticaDatabase, self).__init__(host, port, database, **kwags)
+        super(VerticaDatabase, self).__init__(host, port, database, **kwargs)
         self.user = user
         self.password = password
-        self.read_timeout = read_timeout
+        self.connection_timeout = connection_timeout
         self.type_engine = VerticaTypeEngine()
+        self.log_level = log_level
+
+    def cancel(self, connection):
+        connection.cancel()
 
     def connect(self):
         import vertica_python
 
-        return vertica_python.connect(
+        connection_options = dict(
             host=self.host,
             port=self.port,
             database=self.database,
             user=self.user,
             password=self.password,
-            read_timeout=self.read_timeout,
+            connection_timeout=self.connection_timeout,
             unicode_error="replace",
         )
 
+        if self.log_level:
+            connection_options['log_level'] = self.log_level
+
+        return vertica_python.connect(**connection_options)
+
     def trunc_date(self, field, interval):
         trunc_date_interval = self.DATETIME_INTERVALS.get(str(interval), "DD")
         return Trunc(field, trunc_date_interval)
@@ -92,11 +103,15 @@ class VerticaDatabase(Database):
     def get_column_definitions(self, schema, table, connection=None):
         view_columns, table_columns = Tables('view_columns', 'columns')
 
-        view_query = VerticaQuery.from_(view_columns) \
-            .select(view_columns.column_name, view_columns.data_type) \
-            .where((view_columns.table_schema == Parameter(':schema'))
-                   & (view_columns.field('table_name') == Parameter(':table'))) \
+        view_query = (
+            VerticaQuery.from_(view_columns)
+            .select(view_columns.column_name, view_columns.data_type)
+            .where(
+                (view_columns.table_schema == Parameter(':schema'))
+                & (view_columns.field('table_name') == Parameter(':table'))
+            )
             .distinct()
+        )
 
         table_query = (
             VerticaQuery.from_(table_columns, immutable=False)
@@ -109,9 +124,7 @@ class VerticaDatabase(Database):
         )
 
         return self.fetch(
-            str(view_query + table_query),
-            parameters=dict(schema=schema, table=table),
-            connection=connection
+            str(view_query + table_query), parameters=dict(schema=schema, table=table), connection=connection
         )
 
     def import_csv(self, table, file_path, connection=None):
@@ -134,13 +147,7 @@ class VerticaDatabase(Database):
         :param columns: The columns of the new temporary table.
         :param connection: (Optional) The connection to execute this query with.
         """
-        create_query = (
-            VerticaQuery.create_table(table)
-            .temporary()
-            .local()
-            .preserve_rows()
-            .columns(*columns)
-        )
+        create_query = VerticaQuery.create_table(table).temporary().local().preserve_rows().columns(*columns)
 
         self.execute(str(create_query), connection=connection)
 
@@ -152,13 +159,7 @@ class VerticaDatabase(Database):
         :param select_query: The query to be used for selecting data of an existing table for the new temporary table.
         :param connection: (Optional) The connection to execute this query with.
         """
-        create_query = (
-            VerticaQuery.create_table(table)
-            .temporary()
-            .local()
-            .preserve_rows()
-            .as_select(select_query)
-        )
+        create_query = VerticaQuery.create_table(table).temporary().local().preserve_rows().as_select(select_query)
 
         self.execute(str(create_query), connection=connection)
 
@@ -212,6 +213,4 @@ class VerticaTypeEngine(TypeEngine):
     }
 
     def __init__(self):
-        super(VerticaTypeEngine, self).__init__(
-            self.vertica_to_ansi_mapper, self.ansi_to_vertica_mapper
-        )
+        super(VerticaTypeEngine, self).__init__(self.vertica_to_ansi_mapper, self.ansi_to_vertica_mapper)
