@@ -1,8 +1,9 @@
 import copy
+
 from typing import List
+from pypika import JoinType, terms
 
-from pypika import JoinType, Query
-
+from fireant.dataset.fields import Field, is_metric_field
 from fireant.queries.builder.dataset_query_builder import DataSetQueryBuilder
 from fireant.queries.finders import (
     find_dataset_fields,
@@ -13,15 +14,9 @@ from fireant.queries.finders import (
 )
 from fireant.queries.sql_transformer import make_slicer_query_with_totals_and_references
 from fireant.reference_helpers import reference_type_alias
-from fireant.utils import (
-    alias_selector,
-    listify,
-    ordered_distinct_list_by_attr,
-    filter_nones,
-)
+from fireant.utils import alias_selector, filter_nones, listify, ordered_distinct_list_by_attr
 from fireant.widgets.base import Widget
-from ..sets import apply_set_dimensions, omit_set_filters
-from fireant.dataset.fields import is_metric_field
+from fireant.queries.sets import apply_set_dimensions, omit_set_filters
 
 
 @listify
@@ -109,28 +104,16 @@ def _datasets_and_field_maps(blender_dataset, filters):
             _find_dataset_fields_needed_to_be_mapped(dataset), filters, dataset
         )
 
-        primary_dataset_fields = set(
-            apply_set_dimensions(primary_dataset.fields, filters, primary_dataset)
-        )
-        secondary_dataset_fields = set(
-            apply_set_dimensions(secondary_dataset.fields, filters, secondary_dataset)
-        )
+        primary_dataset_fields = set(apply_set_dimensions(primary_dataset.fields, filters, primary_dataset))
+        secondary_dataset_fields = set(apply_set_dimensions(secondary_dataset.fields, filters, secondary_dataset))
 
-        blender_field_to_primary_field_map = dict(
-            _map_field(primary_dataset_fields, blender_dataset_fields)
-        )
+        blender_field_to_primary_field_map = dict(_map_field(primary_dataset_fields, blender_dataset_fields))
 
-        primary_mapped_dimensions = list(
-            apply_set_dimensions(dataset.dimension_map.keys(), filters, primary_dataset)
-        )
+        primary_mapped_dimensions = list(apply_set_dimensions(dataset.dimension_map.keys(), filters, primary_dataset))
         secondary_mapped_dimensions = list(
-            apply_set_dimensions(
-                dataset.dimension_map.values(), filters, secondary_dataset
-            )
-        )
-        secondary_dimension_per_primary_dimension = dict(
-            zip(primary_mapped_dimensions, secondary_mapped_dimensions)
+            apply_set_dimensions(dataset.dimension_map.values(), filters, secondary_dataset)
         )
+        secondary_dimension_per_primary_dimension = dict(zip(primary_mapped_dimensions, secondary_mapped_dimensions))
 
         blender_field_to_secondary_field_map = dict(
             _map_field(
@@ -157,9 +140,7 @@ def _datasets_and_field_maps(blender_dataset, filters):
                     or blender_field_to_primary_field_map[field] not in fm
                 ):
                     continue
-                remapped_field_map[field] = fm[
-                    blender_field_to_primary_field_map[field]
-                ]
+                remapped_field_map[field] = fm[blender_field_to_primary_field_map[field]]
 
             datasets_and_field_maps.append((ds, remapped_field_map))
 
@@ -190,12 +171,7 @@ def map_blender_field_to_dataset_field(field, field_map, dataset):
 
 
 def map_blender_fields_to_dataset_fields(fields, field_map, dataset):
-    return list(
-        filter_nones(
-            map_blender_field_to_dataset_field(field, field_map, dataset)
-            for field in fields
-        )
-    )
+    return list(filter_nones(map_blender_field_to_dataset_field(field, field_map, dataset) for field in fields))
 
 
 def _build_dataset_query(
@@ -208,12 +184,8 @@ def _build_dataset_query(
     operations,
     share_dimensions,
 ):
-    dataset_references = map_blender_fields_to_dataset_fields(
-        references, field_map, dataset
-    )
-    dataset_share_dimensions = map_blender_fields_to_dataset_fields(
-        share_dimensions, field_map, dataset
-    )
+    dataset_references = map_blender_fields_to_dataset_fields(references, field_map, dataset)
+    dataset_share_dimensions = map_blender_fields_to_dataset_fields(share_dimensions, field_map, dataset)
     dataset_metrics = ordered_distinct_list_by_attr(dataset_metrics)
 
     # TODO: It's possible that we have to adapt/map the operations for @apply_special_cases
@@ -233,9 +205,7 @@ def _build_dataset_query(
     )
 
 
-def _blender_join_criteria(
-    base_query, join_query, dimensions, base_field_map, join_field_map
-):
+def _blender_join_criteria(base_query, join_query, dimensions, base_field_map, join_field_map):
     """
     Build a criteria for joining this join query to the base query in dataset blender queries. This should be a set of
     equality conditions like A0=B0 AND A1=B1 AND An=Bn for each mapped dimension between dataset from
@@ -248,19 +218,61 @@ def _blender_join_criteria(
         if dimension not in base_field_map or dimension not in join_field_map:
             continue
 
-        alias0, alias1 = [
-            alias_selector(field_map[dimension].alias)
-            for field_map in [base_field_map, join_field_map]
-        ]
+        alias0, alias1 = [alias_selector(field_map[dimension].alias) for field_map in [base_field_map, join_field_map]]
 
         next_criteria = base_query[alias0] == join_query[alias1]
-        join_criteria = (
-            next_criteria if join_criteria is None else (join_criteria & next_criteria)
-        )
+        join_criteria = next_criteria if join_criteria is None else (join_criteria & next_criteria)
 
     return join_criteria
 
 
+def _deepcopy_recursive(node):
+    if isinstance(node, terms.ValueWrapper):
+        return node
+
+    cloned_node = copy.deepcopy(node)
+
+    if hasattr(node, 'definition'):
+        cloned_node.definition = _deepcopy_recursive(cloned_node.definition)
+    if hasattr(node, 'term'):
+        cloned_node.term = _deepcopy_recursive(cloned_node.term)
+    if hasattr(node, 'left'):
+        cloned_node.left = _deepcopy_recursive(cloned_node.left)
+    if hasattr(node, 'right'):
+        cloned_node.right = _deepcopy_recursive(cloned_node.right)
+    if hasattr(node, 'value'):
+        cloned_node.value = _deepcopy_recursive(cloned_node.value)
+
+    # Case expressions
+    if hasattr(node, '_cases'):
+        cloned_cases = []
+
+        for (criterion, value) in cloned_node._cases:
+            cloned_cases.append((_deepcopy_recursive(criterion), _deepcopy_recursive(value)))
+
+        cloned_node._cases = cloned_cases
+    if hasattr(node, '_else'):
+        cloned_node._else = _deepcopy_recursive(cloned_node._else)
+
+    # Function expressions
+    if hasattr(node, 'params'):
+        cloned_node.params = [_deepcopy_recursive(param) for param in cloned_node.params]
+    if hasattr(node, 'args'):
+        cloned_node.args = [_deepcopy_recursive(arg) for arg in cloned_node.args]
+
+    # Modifiers
+    if hasattr(cloned_node, 'metric'):
+        cloned_node.metric = _deepcopy_recursive(cloned_node.metric)
+    if hasattr(cloned_node, 'dimension'):
+        cloned_node.dimension = _deepcopy_recursive(cloned_node.dimension)
+    if hasattr(cloned_node, 'filter'):
+        cloned_node.filter = _deepcopy_recursive(cloned_node.filter)
+    if hasattr(cloned_node, 'field'):
+        cloned_node.field = _deepcopy_recursive(cloned_node.field)
+
+    return cloned_node
+
+
 def _get_sq_field_for_blender_field(field, queries, field_maps, reference=None):
     unmodified_field = find_field_in_modified_field(field)
     field_alias = alias_selector(reference_type_alias(field, reference))
@@ -271,84 +283,88 @@ def _get_sq_field_for_blender_field(field, queries, field_maps, reference=None):
             continue
 
         mapped_field = field_map[unmodified_field]
-        mapped_field_alias = alias_selector(
-            reference_type_alias(mapped_field, reference)
-        )
+        mapped_field_alias = alias_selector(reference_type_alias(mapped_field, reference))
 
         subquery_field = query[mapped_field_alias]
         # case #1 modified fields, ex. day(timestamp) or rollup(dimension)
         return field.for_(subquery_field).as_(field_alias)
 
-    # Need to copy the metrics if there are references so that the `get_sql` monkey patch does not conflict
-    definition = copy.deepcopy(field.definition)
+    # Need to copy the metrics if there are references so that the `get_sql` monkey patch does not conflict.
+    # Given some of them might have nested metrics themselves, the clone process is performed recursively.
+
+    definition = field.definition
+
+    while isinstance(definition, Field):
+        definition = definition.definition
+
     # case #2: complex blender fields
-    return definition.as_(field_alias)
+    return _deepcopy_recursive(definition).as_(field_alias)
 
 
-def _perform_join_operations(
-    dimensions, base_query, base_field_map, join_queries, join_field_maps
-):
-    blender_query = Query.from_(base_query, immutable=False)
+def _perform_join_operations(dimensions, base_query, base_field_map, join_queries, join_field_maps):
+    blender_query = base_query.QUERY_CLS.from_(base_query, immutable=False)
     for join_sql, join_field_map in zip(join_queries, join_field_maps):
         if join_sql is None:
             continue
 
-        criteria = _blender_join_criteria(
-            base_query, join_sql, dimensions, base_field_map, join_field_map
-        )
+        criteria = _blender_join_criteria(base_query, join_sql, dimensions, base_field_map, join_field_map)
 
         # In most cases there are dimensions to join the two data blending queries on, but if there are none, then
         # instead of doing a join, add the data blending query to the from clause
         blender_query = (
             blender_query.from_(join_sql)  # <-- no dimensions mapped
             if criteria is None
-            else blender_query.join(join_sql, JoinType.left).on(
-                criteria
-            )  # <-- mapped dimensions
+            else blender_query.join(join_sql, JoinType.left).on(criteria)  # <-- mapped dimensions
         )
 
     return blender_query
 
 
-def _blend_query(dimensions, metrics, orders, field_maps, queries):
+def _blend_query(dimensions, metrics, orders, field_maps, queries, query_builder):
     base_query, *join_queries = queries
     base_field_map, *join_field_maps = field_maps
 
     reference = base_query._references[0] if base_query._references else None
+    blender_query = _perform_join_operations(dimensions, base_query, base_field_map, join_queries, join_field_maps)
 
-    blender_query = _perform_join_operations(
-        dimensions, base_query, base_field_map, join_queries, join_field_maps
-    )
+    mocked_metrics = set()
 
     # WARNING: In order to make complex fields work, the get_sql for each field is monkey patched in. This must
     # happen here because a complex metric by definition references values selected from the dataset subqueries.
-
     for metric in find_dataset_fields(metrics):
-        subquery_field = _get_sq_field_for_blender_field(
-            metric, queries, field_maps, reference
-        )
+        subquery_field = _get_sq_field_for_blender_field(metric, queries, field_maps, reference)
+        metric._origin_get_sql = metric.get_sql
         metric.get_sql = subquery_field.get_sql
+        mocked_metrics.add(metric)
+
+    # WARNING: Artificial dimensions (i.e. dimensions created dynamically), which depend on a metric,
+    # can only be properly mapped once the metrics' get_sql methods are monkey patched. That's the case
+    # for set dimensions. Therefore, dimensions needs to be re-read from the query builder.
+    dimensions = query_builder.dimensions
+
+    sq_dimensions = [_get_sq_field_for_blender_field(d, queries, field_maps) for d in dimensions]
+    sq_metrics = [_get_sq_field_for_blender_field(m, queries, field_maps, reference) for m in metrics]
 
-    sq_dimensions = [
-        _get_sq_field_for_blender_field(d, queries, field_maps) for d in dimensions
-    ]
-    sq_metrics = [
-        _get_sq_field_for_blender_field(m, queries, field_maps, reference)
-        for m in metrics
-    ]
     blender_query = blender_query.select(*sq_dimensions).select(*sq_metrics)
 
     for field, orientation in orders:
-        if any(dimension is field for dimension in dimensions):
-            # Don't add the reference type to dimensions
+        # Comparing fields using the is operator (i.e. object id) doesn't work for set
+        # dimensions, which are dynamically generated. The dunder hash of Field class
+        # does the job properly properly though, given set dimensions are treated
+        # in particular while object id is used for anything else.
+        if not is_metric_field(field):
+            # Don't add the reference type to dimensions.
             orderby_field = _get_sq_field_for_blender_field(field, queries, field_maps)
         else:
-            orderby_field = _get_sq_field_for_blender_field(
-                field, queries, field_maps, reference
-            )
+            orderby_field = _get_sq_field_for_blender_field(field, queries, field_maps, reference)
 
         blender_query = blender_query.orderby(orderby_field, order=orientation)
 
+    # Undo the get_sql's mocks above, otherwise reused datasets might produce different results. This issue can
+    # affect tests, for instance.
+    for metric in mocked_metrics:
+        metric.get_sql = metric._origin_get_sql
+
     return blender_query
 
 
@@ -376,18 +392,12 @@ class DataSetBlenderQueryBuilder(DataSetQueryBuilder):
         datasets, field_maps = _datasets_and_field_maps(self.dataset, self._filters)
 
         selected_blender_dimensions = self.dimensions
-        selected_blender_dimensions_aliases = {
-            dimension.alias for dimension in selected_blender_dimensions
-        }
+        selected_blender_dimensions_aliases = {dimension.alias for dimension in selected_blender_dimensions}
         selected_blender_metrics = find_metrics_for_widgets(self._widgets)
-        selected_blender_metrics_aliases = {
-            metric.alias for metric in selected_blender_metrics
-        }
+        selected_blender_metrics_aliases = {metric.alias for metric in selected_blender_metrics}
 
         operations = find_operations_for_widgets(self._widgets)
-        share_dimensions = find_share_dimensions(
-            selected_blender_dimensions, operations
-        )
+        share_dimensions = find_share_dimensions(selected_blender_dimensions, operations)
         non_set_filters = omit_set_filters(self._filters)
 
         # Add fields to be ordered on, to metrics if they aren't yet selected in metrics or dimensions
@@ -427,9 +437,7 @@ class DataSetBlenderQueryBuilder(DataSetQueryBuilder):
             )
 
             dataset_filters.append(
-                map_blender_fields_to_dataset_fields(
-                    non_set_filters, field_maps[dataset_index], dataset
-                )
+                map_blender_fields_to_dataset_fields(non_set_filters, field_maps[dataset_index], dataset)
             )
 
             # Metric selected from this dataset, so include it.
@@ -482,10 +490,7 @@ class DataSetBlenderQueryBuilder(DataSetQueryBuilder):
                         dataset_dimensions[dataset_index].append(mapped_dimension)
 
                 # Update first_dataset_that_has_the_dimension if needed
-                if (
-                    not dimension_accounted_for
-                    and first_dataset_that_has_the_dimension is None
-                ):
+                if not dimension_accounted_for and first_dataset_that_has_the_dimension is None:
                     first_dataset_that_has_the_dimension = (
                         dataset_index,
                         mapped_dimension,
@@ -518,8 +523,6 @@ class DataSetBlenderQueryBuilder(DataSetQueryBuilder):
                 # Filter the field maps of which the dataset is not going to be in the final query.
                 filtered_field_maps.append(field_maps[dataset_index])
 
-
-
         """
         A dataset query can yield one or more sql queries, depending on how many types of references or dimensions 
         with totals are selected. A blended dataset query must yield the same number and types of sql queries, but each
@@ -536,9 +539,7 @@ class DataSetBlenderQueryBuilder(DataSetQueryBuilder):
         Each set of queries in a column are then reduced to a single data blending sql query.
         """
 
-        per_dataset_queries_count = max(
-            [len(dataset_queries) for dataset_queries in datasets_queries]
-        )
+        per_dataset_queries_count = max([len(dataset_queries) for dataset_queries in datasets_queries])
         # There will be the same amount of query sets as the longest length of queries for a single dataset
         query_sets = [[] for _ in range(per_dataset_queries_count)]
 
@@ -555,6 +556,7 @@ class DataSetBlenderQueryBuilder(DataSetQueryBuilder):
                 self.orders,
                 filtered_field_maps,
                 queryset,
+                self,
             )
             blended_query = self._apply_pagination(blended_query)
 
