@@ -25,15 +25,11 @@ def adjust_daterange_filter_for_rolling_window(dimensions, operations, filters):
         The filters applied to a slicer query
     :return:
     """
-    has_datetime_dimension_in_first_dimension_pos = (
-        not len(dimensions) or not dimensions[0].data_type == DataType.date
-    )
+    has_datetime_dimension_in_first_dimension_pos = not len(dimensions) or not dimensions[0].data_type == DataType.date
     if has_datetime_dimension_in_first_dimension_pos:
         return filters
 
-    has_rolling = any(
-        [isinstance(operation, RollingOperation) for operation in operations]
-    )
+    has_rolling = any([isinstance(operation, RollingOperation) for operation in operations])
     if not has_rolling:
         return filters
 
@@ -41,17 +37,12 @@ def adjust_daterange_filter_for_rolling_window(dimensions, operations, filters):
     filters_on_dim0 = [
         filter_
         for filter_ in filters
-        if isinstance(filter_, RangeFilter)
-        and str(filter_.definition.term) == str(dim0.definition)
+        if isinstance(filter_, RangeFilter) and str(filter_.definition.term) == str(dim0.definition)
     ]
     if not 0 < len(filters_on_dim0):
         return filters
 
-    max_rolling_period = max(
-        operation.window
-        for operation in operations
-        if isinstance(operation, RollingOperation)
-    )
+    max_rolling_period = max(operation.window for operation in operations if isinstance(operation, RollingOperation))
 
     for filter_ in filters_on_dim0:
         # Monkey patch the update start date on the date filter
@@ -77,24 +68,16 @@ def adjust_dataframe_for_rolling_window(operations, data_frame):
     :param data_frame:
     :return:
     """
-    has_rolling = any(
-        [isinstance(operation, RollingOperation) for operation in operations]
-    )
+    has_rolling = any([isinstance(operation, RollingOperation) for operation in operations])
     if not has_rolling:
         return data_frame
 
-    max_rolling_period = max(
-        operation.window
-        for operation in operations
-        if isinstance(operation, RollingOperation)
-    )
+    max_rolling_period = max(operation.window for operation in operations if isinstance(operation, RollingOperation))
 
     if isinstance(data_frame.index, pd.DatetimeIndex):
-        return data_frame.iloc[max_rolling_period - 1:]
+        return data_frame.iloc[max_rolling_period - 1 :]
 
-    if isinstance(data_frame.index, pd.MultiIndex) and isinstance(
-        data_frame.index.levels[0], pd.DatetimeIndex
-    ):
+    if isinstance(data_frame.index, pd.MultiIndex) and isinstance(data_frame.index.levels[0], pd.DatetimeIndex):
         num_levels = len(data_frame.index.levels)
 
         return (
@@ -107,15 +90,8 @@ def adjust_dataframe_for_rolling_window(operations, data_frame):
 
 
 def apply_to_query_args(*, dimensions, operations, filters, **kwargs):
-    filters = adjust_daterange_filter_for_rolling_window(
-        dimensions, operations, filters
-    )
-    return dict(
-        dimensions=dimensions,
-        operations=operations,
-        filters=filters,
-        **kwargs
-    )
+    filters = adjust_daterange_filter_for_rolling_window(dimensions, operations, filters)
+    return dict(dimensions=dimensions, operations=operations, filters=filters, **kwargs)
 
 
 def apply_special_cases(f):
