@@ -1,10 +1,12 @@
 import colorsys
 import re
+
+import numpy as np
+import pandas as pd
+
 from collections import OrderedDict, defaultdict
 from functools import partial
-
-import pandas as pd
-import numpy as np
+from typing import Dict, List, Optional
 
 from fireant.dataset.fields import (
     DataType,
@@ -19,13 +21,14 @@ from fireant.dataset.totals import (
 )
 from fireant.formats import (
     RAW_VALUE,
-    TOTALS_VALUE,
+    TOTALS_LABEL,
     display_value,
     json_value,
     raw_value,
     return_none,
     safe_value,
 )
+from fireant.dataset.references import Reference
 from fireant.reference_helpers import reference_alias
 from fireant.utils import (
     alias_for_alias_selector,
@@ -34,12 +37,9 @@ from fireant.utils import (
     setdeepattr,
     wrap_list,
 )
-from .base import ReferenceItem
-from .pandas import Pandas
+from .base import ReferenceItem, HideField
+from .pandas import F_METRICS_DIMENSION_ALIAS, METRICS_DIMENSION_ALIAS, Pandas, TotalsItem
 
-TOTALS_LABEL = "Totals"
-METRICS_DIMENSION_ALIAS = "metrics"
-F_METRICS_DIMENSION_ALIAS = alias_selector(METRICS_DIMENSION_ALIAS)
 _display_value = partial(display_value, nan_value="", null_value="")
 
 
@@ -47,7 +47,7 @@ def hex_to_rgb(hex_val):
     """
     https://stackoverflow.com/questions/29643352/converting-hex-to-rgb-value-in-python
     """
-    return tuple(int(hex_val[i:i + 2], 16) for i in (0, 2, 4))
+    return tuple(int(hex_val[i : i + 2], 16) for i in (0, 2, 4))
 
 
 def rgb_to_hex(rgb_val):
@@ -63,12 +63,12 @@ def hex_to_hsv(hex_color):
 
 
 class FormattingField:
-    def __init__(self, metric=None, reference=None, operation=None):
+    def __init__(self, metric: Optional[Field] = None, reference: Optional[Reference] = None, operation=None):
         self.metric = metric
         self.reference = reference
         self.operation = operation
 
-    def get_alias(self):
+    def get_alias(self) -> str:
         if self.reference:
             if self.operation:
                 return reference_alias(self.operation, self.reference)
@@ -82,7 +82,7 @@ class FormattingField:
 
 
 class FormattingRule:
-    def __init__(self, field, color, covers_row):
+    def __init__(self, field: Field, color, covers_row):
         self.field = field
         self.color = color
         self.covers_row = covers_row
@@ -102,15 +102,15 @@ class FormattingRule:
         Determines, using the luminance of the background color, whether the text color should be light or dark.
         """
         rgb_bg_color = hex_to_rgb(background_color)
-        luminance = (0.299 * rgb_bg_color[0] + 0.587 * rgb_bg_color[1] + 0.114 * rgb_bg_color[2]) / 255;
-        return 'FDFDFD' if luminance < 0.5 else '212121';
+        luminance = (0.299 * rgb_bg_color[0] + 0.587 * rgb_bg_color[1] + 0.114 * rgb_bg_color[2]) / 255
+        return 'FDFDFD' if luminance < 0.5 else '212121'
 
     def get_field_selector(self):
         return alias_selector(self.field.get_alias())
 
 
 class FormattingConditionRule(FormattingRule):
-    def __init__(self, field, operator, value, color, covers_row=False):
+    def __init__(self, field: Field, operator, value, color, covers_row=False):
         super().__init__(field, color, covers_row)
         self.operator = operator
         self.value = value
@@ -136,7 +136,7 @@ class FormattingHeatMapRule(FormattingRule):
 
     WHITE = 'FFFFFF'
 
-    def __init__(self, field, color, start_color=None, covers_row=False):
+    def __init__(self, field: Field, color, start_color=None, covers_row: bool = False, reverse_heatmap: bool = False):
         super().__init__(field, color, covers_row)
         self.hsv_color = hex_to_hsv(self.color)
         if start_color:
@@ -146,13 +146,13 @@ class FormattingHeatMapRule(FormattingRule):
             self.hsv_start_color = None
         self.saturation_spread = max(0.50, self.hsv_color[1] - 0.05)
         self.min_val, self.value_range = None, None
+        self.reverse_heatmap = reverse_heatmap
 
     def set_min_max(self, min_val, max_val):
         if not self._is_invalid(min_val) and not self._is_invalid(max_val):
             self.min_val = min_val
             self.value_range = max_val - min_val
 
-
     @staticmethod
     def _is_invalid(val):
         return pd.isna(val) or np.isinf(val)
@@ -167,6 +167,8 @@ class FormattingHeatMapRule(FormattingRule):
             return self.WHITE
 
         val_ratio = (value - self.min_val) / self.value_range
+        if self.reverse_heatmap:
+            val_ratio = abs(val_ratio - 1.0)
 
         if self.hsv_start_color is not None:
             if val_ratio <= 0.5:
@@ -206,12 +208,6 @@ def map_index_level(index, level, func):
     return index.map(func)
 
 
-class TotalsItem:
-    alias = TOTALS_VALUE
-    label = TOTALS_LABEL
-    prefix = suffix = precision = None
-
-
 class ReactTable(Pandas):
     """
     This component does not work with react-table out of the box, some customization is needed in order to work with
@@ -241,16 +237,17 @@ class ReactTable(Pandas):
                         defaultSortMethod={(a, b, desc) => ReactTableDefaults.defaultSortMethod(a.raw, b.raw, desc)}>
             </ReactTable>;
     """
+
     def __init__(
         self,
-        metric,
-        *metrics: Field,
-        pivot=(),
-        hide=(),
-        transpose=False,
+        metric: Field,
+        *metrics: List[Field],
+        pivot: Optional[List[Field]] = (),
+        hide: Optional[List[HideField]] = None,
+        transpose: bool = False,
         sort=None,
-        ascending=None,
-        max_columns=None,
+        ascending: Optional[bool] = None,
+        max_columns: Optional[int] = None,
         formatting_rules=(),
     ):
         super(ReactTable, self).__init__(
@@ -261,7 +258,7 @@ class ReactTable(Pandas):
             transpose=transpose,
             sort=sort,
             ascending=ascending,
-            max_columns=max_columns
+            max_columns=max_columns,
         )
         self.formatting_rules_map = defaultdict(list)
         self.min_max_map = {}
@@ -272,12 +269,10 @@ class ReactTable(Pandas):
                 self.min_max_map[field_selector] = [np.inf, -np.inf]
 
     def __repr__(self):
-        return "{}({})".format(
-            self.__class__.__name__, ",".join(str(m) for m in self.items)
-        )
+        return "{}({})".format(self.__class__.__name__, ",".join(str(m) for m in self.items))
 
     @staticmethod
-    def map_hyperlink_templates(df, dimensions):
+    def map_hyperlink_templates(df: pd.DataFrame, dimensions: List[Field]) -> Dict[str, str]:
         """
         Creates a mapping for each dimension to it's hyperlink template if it is possible to create the hyperlink
         template for it.
@@ -305,15 +300,12 @@ class ReactTable(Pandas):
                 continue
 
             required_hyperlink_parameters = [
-                alias_selector(argument[1:-1])
-                for argument in pattern.findall(hyperlink_template)
+                alias_selector(argument[1:-1]) for argument in pattern.findall(hyperlink_template)
             ]
 
             # Check that all of the required dimensions are in the result data set. Only include the hyperlink template
             # in the return value of this function if all are present.
-            unavailable_hyperlink_parameters = set(required_hyperlink_parameters) & set(
-                df.index.names
-            )
+            unavailable_hyperlink_parameters = set(required_hyperlink_parameters) & set(df.index.names)
             if not unavailable_hyperlink_parameters:
                 continue
 
@@ -332,7 +324,7 @@ class ReactTable(Pandas):
         return hyperlink_templates
 
     @staticmethod
-    def format_data_frame(data_frame):
+    def format_data_frame(data_frame: pd.DataFrame) -> pd.DataFrame:
         """
         This function prepares the raw data frame for transformation by formatting dates in the index and removing any
         remaining NaN/NaT values. It also names the column as metrics so that it can be treated like a dimension level.
@@ -347,7 +339,9 @@ class ReactTable(Pandas):
         return data_frame
 
     @staticmethod
-    def transform_index_column_headers(data_frame, field_map, hide_dimension_aliases):
+    def transform_index_column_headers(
+        data_frame: pd.DataFrame, field_map: Dict[str, Field], hide_dimension_aliases: List[str]
+    ) -> List[dict]:
         """
         Convert the un-pivoted dimensions into ReactTable column header definitions.
 
@@ -371,10 +365,7 @@ class ReactTable(Pandas):
             }]
         """
         columns = []
-        if (
-            not isinstance(data_frame.index, pd.MultiIndex)
-            and data_frame.index.name is None
-        ):
+        if not isinstance(data_frame.index, pd.MultiIndex) and data_frame.index.name is None:
             return columns
 
         for f_dimension_alias in data_frame.index.names:
@@ -394,7 +385,9 @@ class ReactTable(Pandas):
         return columns
 
     @staticmethod
-    def transform_data_column_headers(data_frame, field_map):
+    def transform_data_column_headers(
+        data_frame: pd.DataFrame, field_map: Dict[str, Field], hide_metric_aliases: List[str]
+    ) -> List[dict]:
         """
         Convert the metrics into ReactTable column header definitions. This includes any pivoted dimensions, which will
         result in multiple rows of headers.
@@ -404,6 +397,8 @@ class ReactTable(Pandas):
             The result set data frame.
         :param field_map:
             A map to find metrics/operations based on their keys found in the data frame.
+        :param hide_metric_aliases:
+            A set with hide metric aliases.
         :return:
             A list of column header definitions with the following structure.
 
@@ -426,7 +421,7 @@ class ReactTable(Pandas):
             }]
         """
 
-        def get_header(column_value, f_dimension_alias, is_totals):
+        def get_header(column_value, f_dimension_alias: str, is_totals: bool):
             if f_dimension_alias == F_METRICS_DIMENSION_ALIAS or is_totals:
                 item = field_map[column_value]
                 return getattr(item, "label", item.alias)
@@ -462,14 +457,16 @@ class ReactTable(Pandas):
 
             columns = []
             for column_value, group in groups:
+                if column_value in hide_metric_aliases:
+                    continue
+
                 is_totals = column_value in TOTALS_MARKERS | {TOTALS_LABEL}
 
                 # All column definitions have a header
-                column = {
-                    "Header": get_header(column_value, f_dimension_alias, is_totals)
-                }
+                column = {"Header": get_header(column_value, f_dimension_alias, is_totals)}
 
                 level_values = previous_level_values + (column_value,)
+
                 if group is not None:
                     # If there is a group, then drop this index level from the group data frame and recurse to build
                     # sub column definitions
@@ -477,9 +474,11 @@ class ReactTable(Pandas):
                     column["columns"] = _make_columns(next_level_df, level_values)
 
                 else:
-                    column["accessor"] = ".".join(
-                        safe_value(value) for value in level_values
-                    )
+                    column["accessor"] = ".".join(safe_value(value) for value in level_values)
+                    # path_accessor can be useful for front-end code e.g. if specifying a custom accessor function.
+                    # Use cases for this include if the value of the nested column name includes a '.' character,
+                    # which breaks the default nested column access functionality.
+                    column["path_accessor"] = [safe_value(value) for value in level_values]
 
                 if is_totals:
                     column["className"] = "fireant-totals"
@@ -489,14 +488,18 @@ class ReactTable(Pandas):
             return columns
 
         # If the query only has a single metric, that level will be dropped, and set as data_frame.name
-        dropped_metric_level_name = (
-            (data_frame.name,) if hasattr(data_frame, "name") else ()
-        )
+        dropped_metric_level_name = (data_frame.name,) if hasattr(data_frame, "name") else ()
 
         return _make_columns(data_frame.columns.to_frame(), dropped_metric_level_name)
 
     @staticmethod
-    def transform_row_index(index_values, field_map, dimension_hyperlink_templates, hide_dimension_aliases, row_colors):
+    def transform_row_index(
+        index_values,
+        field_map: Dict[str, Field],
+        dimension_hyperlink_templates: Dict[str, str],
+        hide_dimension_aliases: List[str],
+        row_colors: List[str],
+    ):
         # Add the index to the row
         row = {}
         for key, value in index_values.items():
@@ -520,9 +523,7 @@ class ReactTable(Pandas):
             # at this point, otherwise the hyperlink template will not be included.
             if not is_totals and key in dimension_hyperlink_templates:
                 try:
-                    data["hyperlink"] = dimension_hyperlink_templates[key].format(
-                        **index_values
-                    )
+                    data["hyperlink"] = dimension_hyperlink_templates[key].format(**index_values)
                 except KeyError:
                     pass
 
@@ -530,7 +531,8 @@ class ReactTable(Pandas):
             row[safe_key] = data
 
         for dimension_alias in hide_dimension_aliases:
-            del row[dimension_alias]
+            if dimension_alias in row:
+                del row[dimension_alias]
 
         return row
 
@@ -538,22 +540,21 @@ class ReactTable(Pandas):
     def _get_row_value_accessor(series, fields, key):
         index_names = series.index.names or []
 
-        accessor_fields = [
-            fields[field_alias]
-            for field_alias in index_names
-            if field_alias is not None
-        ]
-        accessor = [
-            safe_value(value) for value, field in zip(key, accessor_fields)
-        ] or key
+        accessor_fields = [fields[field_alias] for field_alias in index_names if field_alias is not None]
+        accessor = [safe_value(value) for value, field in zip(key, accessor_fields)] or key
 
         return accessor
 
-    def transform_row_values(self, series, fields, is_transposed, is_pivoted):
+    def transform_row_values(
+        self, series, fields: Dict[str, Field], is_transposed: bool, is_pivoted: bool, hide_aliases: List[str]
+    ):
         row = {}
         row_colors = None
 
         for key, value in series.items():
+            if key in hide_aliases:
+                continue
+
             key = wrap_list(key)
 
             # Get the field for the metric
@@ -589,7 +590,7 @@ class ReactTable(Pandas):
 
         return row, row_colors
 
-    def calculate_min_max(self, df, is_transposed):
+    def calculate_min_max(self, df: pd.DataFrame, is_transposed: bool):
         if not self.min_max_map:
             return
 
@@ -609,8 +610,14 @@ class ReactTable(Pandas):
                     rule.set_min_max(*self.min_max_map[rule.get_field_selector()])
 
     def transform_data(
-        self, data_frame, field_map, hide_aliases, dimension_hyperlink_templates, is_transposed, is_pivoted,
-    ):
+        self,
+        data_frame: pd.DataFrame,
+        field_map: Dict[str, Field],
+        hide_aliases: List[str],
+        dimension_hyperlink_templates: Dict[str, str],
+        is_transposed: bool,
+        is_pivoted: bool,
+    ) -> List[dict]:
         """
         Builds a list of dicts containing the data for ReactTable. This aligns with the accessors set by
         #transform_dimension_column_headers and #transform_metric_column_headers
@@ -652,14 +659,14 @@ class ReactTable(Pandas):
 
         rows = []
         for index, series in data_frame.iterrows():
-            row_values, row_colors = self.transform_row_values(series, field_map, is_transposed, is_pivoted)
+            row_values, row_colors = self.transform_row_values(
+                series, field_map, is_transposed, is_pivoted, hide_aliases
+            )
 
             index = wrap_list(index)
             # Get a list of values from the index. These can be metrics or dimensions so it checks in the item map if
             # there is a display value for the value
-            index_values = (
-                [_get_field_label(value) for value in index] if is_transposed else index
-            )
+            index_values = [_get_field_label(value) for value in index] if is_transposed else index
             index_display_values = OrderedDict(zip(index_names, index_values))
             row_index = self.transform_row_index(
                 index_display_values, field_map, dimension_hyperlink_templates, hide_aliases, row_colors
@@ -675,12 +682,12 @@ class ReactTable(Pandas):
 
     def transform(
         self,
-        data_frame,
-        dimensions,
-        references,
-        annotation_frame=None,
-        use_raw_values=False,
-    ):
+        data_frame: pd.DataFrame,
+        dimensions: List[Field],
+        references: List[Reference],
+        annotation_frame: Optional[pd.DataFrame] = None,
+        use_raw_values: bool = False,
+    ) -> dict:
         """
         Transforms a data frame into a format for ReactTable. This is an object containing attributes `columns` and
         `data` which align with the props in ReactTable with the same name.
@@ -701,9 +708,7 @@ class ReactTable(Pandas):
         """
         result_df = data_frame.copy()
 
-        dimension_map = {
-            alias_selector(dimension.alias): dimension for dimension in dimensions
-        }
+        dimension_map = {alias_selector(dimension.alias): dimension for dimension in dimensions}
 
         metric_map = OrderedDict(
             [
@@ -730,13 +735,7 @@ class ReactTable(Pandas):
         }
         metric_aliases = list(metric_map.keys())
 
-        hide_aliases = {
-            alias_selector(dimension.alias) for dimension in self.hide
-        }
-
-        for dimension in dimensions:
-            if dimension.fetch_only:
-                hide_aliases.add(alias_selector(dimension.alias))
+        hide_aliases = self.hide_aliases(dimensions)
 
         pivot_dimensions = [
             alias_selector(dimension.alias)
@@ -747,7 +746,7 @@ class ReactTable(Pandas):
         result_df = self.format_data_frame(result_df[metric_aliases])
         result_df, is_pivoted, is_transposed = self.pivot_data_frame(result_df, pivot_dimensions, self.transpose)
         dimension_columns = self.transform_index_column_headers(result_df, field_map, hide_aliases)
-        metric_columns = self.transform_data_column_headers(result_df, field_map)
+        metric_columns = self.transform_data_column_headers(result_df, field_map, hide_aliases)
 
         data = self.transform_data(
             result_df,
